==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/petitions/lang/petitions_oc_lnc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Vous allez supprimer toutes les signatures de cette p&eacute;tition. &Ecirc;tes-vous sur de vouloir continuer ?', # NEW
	'aucune_signature' => 'Aucune signature', # NEW

	// B
	'bouton_checkbox_envoi_message' => 'possibilit&eacute; d\'envoyer un message', # NEW
	'bouton_checkbox_indiquer_site' => 'indiquer obligatoirement un site web', # NEW
	'bouton_checkbox_signature_unique_email' => 'une seule signature par adresse email', # NEW
	'bouton_checkbox_signature_unique_site' => 'une seule signature par site web', # NEW

	// F
	'filtre' => 'Filtre :', # NEW
	'form_pet_adresse_site' => 'Adreiça de vòstre sit', # MODIF
	'form_pet_aucune_signature' => 'Cap de signatura correspond pas a aquel còde...',
	'form_pet_confirmation' => 'Volgatz confirmar vòstra signatura :',
	'form_pet_deja_signe' => 'Avètz ja signat aquel tèxt.',
	'form_pet_envoi_mail_confirmation' => 'Ara recebretz un e-mail de confirmacion. Per validar vòstra signatura, cal vesitar l\'adreiça web mençonada per aqueste corrièr.', # MODIF
	'form_pet_mail_confirmation' => 'Bonjorn,

avètz demandat de signar la peticion:
@titre@.

Avètz fornidas las informacions seguentas:
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@
    @message@


IMPORTANT...
Per validar vòstra signatura, basta de vos connectar a 
 l\'adreiça çai sota (senon s\'escamparà
vòstra demanda): 
    @url@


Mercés per vòstra participacion
',
	'form_pet_message_commentaire' => 'Un messatge, una remarca ?', # MODIF
	'form_pet_nom_site2' => 'Nom de vòstre sit Web', # MODIF
	'form_pet_probleme_liens' => 'Volgatz tornar prene vòstre messatge en supprimir los ligams ipertèxt.',
	'form_pet_probleme_technique' => 'Problèma tecnic, las signaturas son temporàriament arrestadas.',
	'form_pet_signature_validee' => 'Vòstra signatura es validada. Mercés!',
	'form_pet_site_deja_enregistre' => 'Ja aquel sit es registrat',
	'form_pet_url_invalide' => 'L\'URL qu\'avètz indicada es pas valida.',
	'form_pet_votre_email' => 'Vòstra adreiça e-mail',
	'form_pet_votre_nom' => 'Vòstre nom o pseudonim', # MODIF
	'form_pet_votre_site' => 'Se tenètz un sit, o podètz marcar çai sota',

	// I
	'icone_relancer_signataire' => 'Relancer le signataire', # NEW
	'icone_relancer_signataires' => 'Relancer les signataires', # NEW
	'icone_suivi_petitions' => 'Suivre/g&eacute;rer les p&eacute;titions', # NEW
	'icone_supprimer_signature' => 'Supprimer cette signature', # NEW
	'icone_supprimer_signatures' => 'Supprimer les signatures', # NEW
	'icone_valider_signature' => 'Valider cette signature', # NEW
	'icone_valider_signatures' => 'Valider les signatures', # NEW
	'info_adresse_email' => 'ADREIÇA E-MAIL :',
	'info_fonctionnement_petition' => 'Fonctionnement de la p&eacute;tition :', # NEW
	'info_signature_supprimee' => 'Signatura suprimida',
	'info_signature_supprimee_erreur' => 'Error : aquel còde de suppression correspond pas a a cap de signatura',
	'info_site_web' => 'SIT WEB:',
	'info_texte_message' => 'Tèxt del vòstre messatge:',

	// L
	'lien_reponse_article' => 'Responsa a l\'article',

	// N
	'nombre_signatures' => '@nb@ signatures', # NEW

	// S
	'sans_nom' => 'Anonyme', # NEW
	'signatures_article' => 'Signatures de l\'article :', # NEW
	'signatures_aucune' => 'Aucune', # NEW
	'signatures_meme_auteur' => 'Les signatures du m', # NEW
	'signatures_meme_site' => 'Les signatures avec le m', # NEW
	'signatures_poubelle' => 'Supprim&eacute;es', # NEW
	'signatures_prop' => 'En attente', # NEW
	'signatures_publie' => 'Confirm&eacute;es', # NEW
	'signatures_recherche_label' => 'Rechercher des signatures&nbsp;:', # NEW
	'signatures_toutes' => 'Toutes', # NEW
	'statut_poubelle' => 'Supprim&eacute;e', # NEW
	'statut_prop' => 'En attente de validation', # NEW
	'statut_publie' => 'Confirm&eacute;e', # NEW

	// T
	'texte_descriptif_petition' => 'Descriptif de la p&eacute;tition', # NEW
	'titre_page_controle_petition' => 'Suivi des p&eacute;titions', # NEW
	'titre_petition' => 'P&eacute;tition', # NEW
	'titre_petitions' => 'P&eacute;titions', # NEW
	'titre_selection_action' => 'Sélection', # NEW
	'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
	'titre_signatures_publie' => 'Signatures confirm&eacute;es', # NEW
	'titre_suivi_petition' => 'Suivi des p&eacute;titions', # NEW
	'tout_voir' => 'Voir toutes les signatures', # NEW

	// U
	'une_signature' => '1 signature', # NEW

	// V
	'voir_signatures_objet' => 'Voir les signatures' # NEW
);

?>

==> spip_3.1~21100.orig.tar.xz: spip-3.1~21100.orig/plugins-dist/petitions/lang/petitions_oc_lnc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=oc_lnc
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Activar la peticion',
	'bouton_radio_pas_petition' => 'Pas cap de peticion',
	'bouton_radio_petition_activee' => 'Peticion activada',
	'bouton_radio_supprimer_petition' => 'Suprimir la peticion',

	// F
	'form_pet_adresse_site' => 'Adreiça de vòstre sit', # MODIF
	'form_pet_aucune_signature' => 'Cap de signatura correspond pas a aquel còde...', # MODIF
	'form_pet_confirmation' => 'Volgatz confirmar vòstra signatura :',
	'form_pet_deja_signe' => 'Avètz ja signat aquel tèxt.',
	'form_pet_envoi_mail_confirmation' => 'Ara recebretz un e-mail de confirmacion. Per validar vòstra signatura, cal vesitar l’adreiça web mençonada per aqueste corrièr.', # MODIF
	'form_pet_mail_confirmation' => 'Bonjorn,

avètz demandat de signar la peticion:
@titre@.

Avètz fornidas las informacions seguentas:
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@
    @message@


IMPORTANT...
Per validar vòstra signatura, basta de vos connectar a 
 l’adreiça çai sota (senon s’escamparà
vòstra demanda): 
    @url@


Mercés per vòstra participacion
',
	'form_pet_nom_site2' => 'Nom de vòstre sit Web', # MODIF
	'form_pet_probleme_liens' => 'Volgatz tornar prene vòstre messatge en supprimir los ligams ipertèxt.',
	'form_pet_probleme_technique' => 'Problèma tecnic, las signaturas son temporàriament arrestadas.',
	'form_pet_signature_validee' => 'Vòstra signatura es validada. Mercés!',
	'form_pet_site_deja_enregistre' => 'Ja aquel sit es registrat',
	'form_pet_url_invalide' => 'L’URL qu’avètz indicada es pas valida.',
	'form_pet_votre_email' => 'Vòstra adreiça e-mail',
	'form_pet_votre_nom' => 'Vòstre nom o pseudonim', # MODIF
	'form_pet_votre_site' => 'Se tenètz un sit, o podètz marcar çai sota',

	// I
	'info_adresse_email' => 'ADREIÇA E-MAIL :',
	'info_signature_supprimee' => 'Signatura suprimida',
	'info_signature_supprimee_erreur' => 'Error : aquel còde de suppression correspond pas a a cap de signatura', # MODIF
	'info_site_web' => 'SIT WEB:',

	// L
	'lien_reponse_article' => 'Responsa a l’article'
);

?>
